@@ -6,8 +6,8 @@ import os, sys
 import pystan
 import pickle
 ##
-import SFH_3D_plot_no_scaled as sf3p_ns
-import Marginal_SFH_Bar_NoScale as mgl_b_ns
+#import SFH_3D_plot_no_scaled as sf3p_ns
+#import Marginal_SFH_Bar_NoScale as mgl_b_ns
 
 
 
